@@ -3,11 +3,11 @@ test_that("associate_coordinates is stable", {
   # Being not in the possession of M1 macs nor the ability to fix terra,
   # I am temporarily skipping this test until one of those things changes
   skip_on_os(os = "mac", arch = "aarch64")
-  expect_identical(
-    associate_coordinates(
+  out <- associate_coordinates(
       sf::st_as_sf(data.frame(x = 5, y = 5), coords = c("x", "y"), crs = "EPSG:5071"),
       terra::rast(matrix(data = rep(1, 100), nrow = 10), crs = "EPSG:5071")
-    ),
-    data.frame(X = 4092, Y = 5, row.names = "1")
-  )
+    )
+
+  expect_equal(out$X, 4092)
+  expect_equal(out$Y, 5)
 })
